package org.apache.maven.archiva.scheduler.executors;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.commons.io.FileUtils;
import org.apache.maven.archiva.configuration.ArchivaConfiguration;
import org.apache.maven.archiva.configuration.Configuration;
import org.apache.maven.archiva.scheduler.task.DataRefreshTask;
import org.codehaus.plexus.PlexusTestCase;
import org.codehaus.plexus.taskqueue.execution.TaskExecutionException;
import org.codehaus.plexus.taskqueue.execution.TaskExecutor;

import java.io.File;

/**
 * IndexerTaskExecutorTest
 *
 * @author <a href="mailto:joakime@apache.org">Joakim Erdfelt</a>
 * @version $Id: DataRefreshExecutorTest.java 511053 2007-02-23 19:05:21Z joakime $
 */
public class DataRefreshExecutorTest
    extends PlexusTestCase
{
    private TaskExecutor taskExecutor;

    protected void setUp()
        throws Exception
    {
        super.setUp();

        taskExecutor = (TaskExecutor) lookup( "org.codehaus.plexus.taskqueue.execution.TaskExecutor", "data-refresh" );

        ArchivaConfiguration archivaConfiguration =
            (ArchivaConfiguration) lookup( ArchivaConfiguration.class.getName() );
        Configuration configuration = archivaConfiguration.getConfiguration();

        File indexPath = new File( configuration.getIndexPath() );
        if ( indexPath.exists() )
        {
            FileUtils.deleteDirectory( indexPath );
        }
    }

    public void testExecutor()
        throws TaskExecutionException
    {
        taskExecutor.executeTask( new TestDataRefreshTask() );
    }

    class TestDataRefreshTask
        extends DataRefreshTask
    {
        public String getJobName()
        {
            return "TestDataRefresh";
        }
    }
}
